pub trait BazelPath {
// Required method
fn unbazelify(&self) -> Result<PathBuf>;
}Required Methods
Sourcefn unbazelify(&self) -> Result<PathBuf>
fn unbazelify(&self) -> Result<PathBuf>
Resolve the given path to an absolute path in a Bazel-aware manner.
If the current program was run via bazel run, relative paths will be resolved using the
directory the bazel command was run from. Otherwise, it resolves relative paths against the
current working directory. Absolute paths are left as is.
Errors
Returns an Err if the current working directory could not be determined, e.g. because it
does not exist or there are insufficient permissions to access it.